<?php

namespace Drupal\demo_slideshow\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Field\FormatterBase;

/**
 * Plugin implementation of the 'image_slideshow' field type.
 *
 * @FieldType(
 *   id = "image_slideshow",
 *   label = @Translation("Image Slideshow"),
 *   description = @Translation("Stores image references for a slideshow."),
 *   default_widget = "image_image",
 *   default_formatter = "image_slideshow_formatter"
 * )
 */
class ImageSlideshow extends FieldItemBase {

  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties = [];
    $properties['target_id'] = DataDefinition::create('integer')
      ->setLabel(t('Image target ID'));
    return $properties;
  }

  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return [
      'columns' => [
        'target_id' => [
          'type' => 'int',
          'unsigned' => TRUE,
        ],
      ],
      'indexes' => [
        'target_id' => ['target_id'],
      ],
    ];
  }

  public function isEmpty() {
    $value = $this->get('target_id')->getValue();
    return empty($value);
  }
}
